<?php

/**
 * This module checks if subfolders miss an index.php
 *
 * @module          check_folder_secure
 * @author          Wolfgang Studer
 * @copyright       2015-2015 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.03.000 | 2015-11-17
 */

// include class.secure.php to protect this file and the whole CMS!
if ( defined('LEPTON_PATH') == TRUE ):	
	include(LEPTON_PATH.'/framework/class.secure.php');
else:
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.'/framework/class.secure.php'))):
		$root .= $oneback;
		$level += 1;
	endwhile;
	
	if (file_exists($root.'/framework/class.secure.php')):
		include($root.'/framework/class.secure.php');
	else:
		trigger_error(sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	endif;
endif;
// end include class.secure.php

// build list of all directories starting from input path missing a specific file
function recursiveDirectoryIterator ( $directory = null, $folders = array(), $searchFiles = array() )
{
	$iterator = new DirectoryIterator ( $directory );

	$searchFileFound = FALSE;

	foreach ( $iterator as $fileinfo ):
		if (( $fileinfo->isDot() == FALSE ) && ( $fileinfo->isDir() == TRUE )):
			$folders = recursiveDirectoryIterator ( $directory . DIRECTORY_SEPARATOR . $fileinfo->getFilename() , $folders, $searchFiles );
		elseif (( $fileinfo->isFile() == TRUE ) && ( in_array( strtolower( $fileinfo->getFilename()), $searchFiles ) == TRUE )):
			$searchFileFound = TRUE;
		endif;
	endforeach;

	if ( $searchFileFound == FALSE ):
		$folders[] = $directory ;
	endif;

	return $folders;
}

// create a table row per item for a dedicated group
function showFolderGroup ( $type = '', &$folders = array() )
{
	global $CHECKFOLDERSECURE;
	global $processed;
	global $groups;

	// build header block
	$header = '';
	$header .= '		<tr>' . PHP_EOL;
	$header .= '			<td colspan="4">' . PHP_EOL;
	$header .= '				<h2>' . $CHECKFOLDERSECURE[ strtoupper( $type ) ] . '</h2>' . PHP_EOL;
	$header .= '			</td>' . PHP_EOL;
	$header .= '		</tr>' . PHP_EOL;

	// build data block
	$detail = '';
	foreach( $folders as $key => $folder ):
		// define visible part of link
		$show = str_replace( LEPTON_PATH, '', $folder );
		
		// check if current page in target group
		$itemFound = FALSE;
		if ( $groups[0] == '*' ):
			$itemFound = TRUE;
		else:
			$item = explode( DIRECTORY_SEPARATOR, $show );
			$itemFound = in_array( $item[1], $groups );
		endif;
		
		// add detail content
		if ( $itemFound == TRUE ):
			// check if current folder is in array of already processed folders
			$class = "tbd";
			if ( isset( $processed[ "F" . $key ] ) == TRUE ):
				// check if index file exists in this folder
				$file = $folder . DIRECTORY_SEPARATOR . 'index' . PAGE_EXTENSION;
				if ( file_exists( $file ) == TRUE ):
					// if yes, use class OK
					$class = "ok";
				else:
					// if not, then there was an error in previous processing, use class WARNING
					$class = "warning";
				endif;
			endif;
			
			$detail .= '		<tr class="' . $class . '">' . PHP_EOL;
			$detail .= '			<td colspan="3">' . PHP_EOL;
			$url = str_replace( LEPTON_PATH, LEPTON_URL, $folder );
			$detail .= '<a href="' . $url . '" target="_blank">' . $show . '</a>' . PHP_EOL;
			$detail .= '			</td>' . PHP_EOL;
			$detail .= '			<td>' . PHP_EOL;
			if ( $class == "ok" ):
				$detail .= '&nbsp;' . PHP_EOL;
			else:
				$detail .= '				<input type="submit" name="S' . $key . '" value="' . $CHECKFOLDERSECURE['SUBMIT'] . '" />' . PHP_EOL;
				$detail .= '				<input type="hidden" name="F' . $key . '" value="' . $folder . '" />' . PHP_EOL;
			endif;
			$detail .= '			</td>' . PHP_EOL;
			$detail .= '		</tr>' . PHP_EOL;
			
			// remove item from array
			unset($folders[ $key ]);
		endif;
	endforeach;

	if ( strlen( $detail ) > 0 ):
		return $header . $detail;
	endif;
	return '';
}


// create header info block
function showHeader ()
{
	global $CHECKFOLDERSECURE;

	// build header block
	$header = '';
	$header .= '		<tr>' . PHP_EOL;
	$header .= '			<td colspan="4">' . PHP_EOL;
	$header .= '				<p class="headerhint">' . $CHECKFOLDERSECURE[ 'HEADERHINT' ] . '</p>' . PHP_EOL;
	$header .= '				<hr />' . PHP_EOL;
	$header .= '			</td>' . PHP_EOL;
	$header .= '		</tr>' . PHP_EOL;

	return $header;
}

?>
